https://packaging.python.org/en/latest/tutorials/packaging-projects/

# Example Package

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

python3 -m pip install --upgrade build
python -m build
pip install --upgrade setuptools

python3 -m pip install --upgrade pip
python3 -m build
